# Community Code of Conduct

## Our Standards

Examples of behavior that contribute to our environment:

* Demonstrating empathy and kindness toward other people
* Learning from experience

Examples of behavior that are detrimental to our environment:

* The use of language or imagery that causes others to not feel safe
* Trolling, harassment, insulting comments, and personal attacks
* Private correspondence
* Publishing private information, such as a physical or email
  address, including your own

## Enforcement Responsibilities

Community leaders are responsible for clarifying and enforcing our standards of
acceptable behavior and will take appropriate corrective action in
response to any behavior that they deem inappropriate, threatening, offensive,
or harmful.

Community leaders have the right and responsibility to remove, edit, or reject
comments, commits, code, wiki edits, issues, and other contributions that are
not aligned to this Code of Conduct, and will communicate reasons for moderation
decisions when appropriate.

## Scope

This Code of Conduct applies within all community spaces, and it especially applies
when an individual is officially representing the community. Community members are
expected to know community standards and anticipate the consequences of their 
behavior by observing the actions of others within the community.

## Enforcement Guidelines

Community leaders will follow these Community Impact Guidelines in determining
the consequences for any action they deem in violation of this Code of Conduct:

### 1. Temporary Ban

**Impact**: A violation of community standards.

**Consequence**: A temporary ban from any sort of interaction or public
communication with the community for a specified period of time. No public or
private interaction with the people involved, including unsolicited interaction
with those enforcing the Code of Conduct, is allowed during this period.
Violating these terms may lead to a permanent ban.

### 2. Permanent Ban

**Impact**: Demonstrating a pattern of violation of community
standards, including sustained behavior, targeted harassment of an
individual, or aggression toward or disparagement of classes of individuals.

**Consequence**: A permanent ban from any sort of public interaction within
the community.
